summaryrefslogtreecommitdiffstats
path: root/style
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-26 14:23:44 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-26 14:23:44 -0600
commitedf49c58b5dfbf2857b5e819c8ed875f708824dd (patch)
tree663ef407604bbd62502fb1800129e7b841ca0133 /style
parent96837efb84aae682892d7ac79c3b5a251ddec63b (diff)
downloadtde-style-qtcurve-edf49c58b5dfbf2857b5e819c8ed875f708824dd.tar.gz
tde-style-qtcurve-edf49c58b5dfbf2857b5e819c8ed875f708824dd.zip
Rename kde-config to tde-config
Diffstat (limited to 'style')
-rw-r--r--style/qtcurve.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/style/qtcurve.cpp b/style/qtcurve.cpp
index 09b03d3..1ca6376 100644
--- a/style/qtcurve.cpp
+++ b/style/qtcurve.cpp
@@ -258,12 +258,12 @@ static TQString kdeHome(bool trinity=false)
{
static TQString kdeHome[2];
// Execute kde-config to ascertain users TDEHOME
if(kdeHome[trinity ? 0 : 1].isEmpty())
{
FILE *fpipe;
- if (fpipe = (FILE*)popen(trinity ? "kde-config --localprefix 2> /dev/null" : "kde4-config --localprefix 2> /dev/null", "r"))
+ if (fpipe = (FILE*)popen(trinity ? "tde-config --localprefix 2> /dev/null" : "kde4-config --localprefix 2> /dev/null", "r"))
{
char line[1024];
@@ -258,12 +258,12 @@ static TQString kdeHome(bool trinity=false)
{
static TQString kdeHome[2];
- // Execute kde-config to ascertain users TDEHOME
+ // Execute tde-config to ascertain users TDEHOME
if(kdeHome[trinity ? 0 : 1].isEmpty())
{